@@ -114,7 +114,7 @@ QList<Move> ChessRules::legalMoves ( const Pos& pos ) {
 	Color color = m_grid->value ( pos )->color();
 	switch ( m_grid->value ( pos )->pieceType() ) {
 	case King:
-		for ( const Pos& d : qAsConst(directions) ) {
+		for ( const Pos& d : std::as_const(directions) ) {
 			for ( const Move& m : movesInDirection ( d, pos, 1 ) )
 				moves << m;
 		}
@@ -122,19 +122,19 @@ QList<Move> ChessRules::legalMoves ( const Pos& pos ) {
 		moves << castlingMoves ( pos );
 		break;
 	case Queen:
-		for ( const Pos& d : qAsConst(directions) )
+		for ( const Pos& d : std::as_const(directions) )
 			moves << movesInDirection ( d, pos );
 		break;
 	case Bishop:
-		for ( const Pos& d : qAsConst(diagDirs) )
+		for ( const Pos& d : std::as_const(diagDirs) )
 			moves << movesInDirection ( d, pos );
 		break;
 	case Rook:
-		for ( const Pos& d : qAsConst(lineDirs) )
+		for ( const Pos& d : std::as_const(lineDirs) )
 			moves << movesInDirection ( d, pos );
 		break;
 	case Knight:
-		for ( const Pos& d : qAsConst(knightDirs) ) {
+		for ( const Pos& d : std::as_const(knightDirs) ) {
 			if ( !Board::isInBoard ( pos + d ) )
 				continue;
 			if ( !m_grid->contains ( pos + d ) )
@@ -145,7 +145,7 @@ QList<Move> ChessRules::legalMoves ( const Pos& pos ) {
 		break;
 	case Pawn:
 		moves << pawnMoves ( pos );
-		for ( const Move& m : qAsConst(m_enPassantMoves) ) {
+		for ( const Move& m : std::as_const(m_enPassantMoves) ) {
 			if ( m.from() == pos )
 				moves << m;
 		}
@@ -156,7 +156,7 @@ QList<Move> ChessRules::legalMoves ( const Pos& pos ) {
 
 	//from the list of possible moves, remove those moves where the king would be under attack
 	Pos currKingPos = kingPos[color];
-	for ( const Move& m : qAsConst(moves) ) {
+	for ( const Move& m : std::as_const(moves) ) {
 		Grid t_grid = *m_grid;
 		t_grid.insert ( m.to(), t_grid.take ( pos ) );
 		if ( ( isKingMoving && isAttacked ( m.to(), color, &t_grid ) ) || ( !isKingMoving && isAttacked ( currKingPos, color, &t_grid ) ) ) {
@@ -173,23 +173,23 @@ QList<Move> ChessRules::legalAttackMoves ( const Pos& pos, Grid* grid ) {
 	QList<Move> moves;
 	switch ( grid->value ( pos )->pieceType() ) {
 	case King:
-		for ( const Pos& d : qAsConst(directions) )
+		for ( const Pos& d : std::as_const(directions) )
 			moves << movesInDirection ( d, pos, 1, true, grid );
 		break;
 	case Queen:
-		for ( const Pos& d : qAsConst(directions) )
+		for ( const Pos& d : std::as_const(directions) )
 			moves << movesInDirection ( d, pos, 8, true, grid );
 		break;
 	case Bishop:
-		for ( const Pos& d : qAsConst(diagDirs) )
+		for ( const Pos& d : std::as_const(diagDirs) )
 			moves << movesInDirection ( d, pos, 8, true, grid );
 		break;
 	case Rook:
-		for ( const Pos& d : qAsConst(lineDirs) )
+		for ( const Pos& d : std::as_const(lineDirs) )
 			moves << movesInDirection ( d, pos, 8, true, grid );
 		break;
 	case Knight:
-		for ( const Pos& d : qAsConst(knightDirs) ) {
+		for ( const Pos& d : std::as_const(knightDirs) ) {
 			if ( Board::isInBoard ( pos + d ) )
 				moves << Move ( pos, pos + d );
 		}
@@ -401,7 +401,7 @@ QList< Move > ChessRules::pawnMoves ( const Pos& pos ) {
 			list << Move ( pos, pos + 2*forwardDirection );
 	}
 	// Normal capturing
-	for ( const Pos& captureDir : qAsConst(captureDirections) ) {
+	for ( const Pos& captureDir : std::as_const(captureDirections) ) {
 		if ( m_grid->contains ( pos + captureDir ) && m_grid->value ( pos + captureDir )->color() != m_grid->value ( pos )->color() )
 			list << Move ( pos, pos + captureDir, Move::Take );
 	}
@@ -435,8 +435,8 @@ void ChessRules::moveMade ( const Move& m ) {
 	case Pawn:
 		if ( length ( m ) == 2 ) {
 			Pos mid = ( m.to() + m.from() ) / 2;
-			QList<Direction> dirs = QList<Direction>() << W << E;
-			for ( Direction dir : qAsConst(dirs) )
+			const QList<Direction> dirs {W, E};
+			for ( Direction dir : dirs )
 				if ( m_grid->contains ( m.to() + directions[dir] ) ) {
 					Move enPassantMove;
 					enPassantMove.setFrom ( m.to() + directions[dir] );
@@ -626,7 +626,7 @@ void ChessRules::changeNotation ( Move* move, Move::Notation notation, Color col
 
 		qCDebug(LOG_KNIGHTS) << possibilities;
 
-		for ( const QString& text : qAsConst(possibilities) ) {
+		for ( const QString& text : std::as_const(possibilities) ) {
 			Move m ( text );
 			checkSpecialFlags ( &m, color );
 			if ( m.isValid() ) {
